/* 	MapEntry.java
 *	Copyright 	(c) 2002-2007, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
 * [When]		[Who]					[What]
 * Jun 19, 2007	dennis@brains2b.nl      Implemented equals (regression)		
*/
package org.brains2b.collection;

import java.util.Map.Entry;

/** 
 * A straightforward implementation of the Map.Entry interface outside the Map class
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10.1 [19-06-2007]
 * @since TwelBox 0.30
 * @see java.util.Map.Entry
 */
public class MapEntry implements Entry {

	private Object m_key;
	private Object m_value;

	/**
	 * Default Constructor for MapEntry.
	 */
	public MapEntry() {
		super();
	}
	
	/**
	 * Constructor for MapEntry.
	 * <p>Initializes the MapEntry with key. use setValue to set the value
	 * @param key Object
	 */
	public MapEntry(Object key) {
		m_key=key;
	}
	
	/**
	 * Constructor for MapEntry.
	 * <p>Initializes the MapEntry with key and value
	 * @param key Object
	 * @param value Object
	 */
	public MapEntry(Object key, Object value) {
		m_key=key;
		m_value=value;
	}

	/**
	 * @see java.util.Map.Entry#getKey()
	 */
	public Object getKey() {
		return m_key;
	}

	/**
	 * @see java.util.Map.Entry#getValue()
	 */
	public Object getValue() {
		return m_value;
	}

	/**
	 * @see java.util.Map.Entry#setValue(Object)
	 */
	public Object setValue(Object value) {
		Object old=m_value;
		m_value=value;
		return old;
	}

	/**
	 * sets the Key
	 * <p>Prefered method is using the Constructor to initialize the object with at least the key
	 * instead of setting or updating the key here.
	 * @param key String
	 */
	public Object setKey(Object key) {
		Object old=m_key;
		m_key=key;
		return old;
	}

    /**
     * Compares this EntryImpl to another object to see if they are equal
     * <UL>The following rules apply: 
     * <LI> If comparing a EntryImpl equals returns true if they have the same key
     * <LI>If comparing a String equals returns true if the String equals the key
     * <LI>In all other cases false is returned.
     * @see java.lang.Object#equals(Object)
     */
    public boolean equals(Object obj) {
    	if (obj instanceof MapEntry && ((MapEntry) obj).getKey().equals(m_key)) {
    		return true;
    	} else if (obj instanceof String && obj.equals(m_key)) {
    		return true;
    	}
    	return false;
    		
    }
    
    
}
