/* 	HexHelper.java
 *	Copyright (c) 2006, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: 2-aug-2006
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.brains2b.util;
/** HexHelper decodes and encodes to hexadecimal values.
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [2-aug-2006]
*/
public class HexHelper {

    private static final char[] CHARS = {
        '0', '1', '2', '3', '4', '5', '6', '7',
           '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'
    };
    
    /**
     * encode an array of bytes into a hexidecimal String
     * <p>The string is supplied without any prefix
     * @param b byte[], the array to encode
     * @return the hexidecimal String
     * @throws NullPointerException if no bytes were supplied
     */
    public final static String encode(byte[] b) {
        if (b==null) throw new NullPointerException("no bytes to digest");
        char[] chars=new char[b.length*2];
        for (int i=0;i<b.length;i++) {
          chars[i*2]    =   CHARS[(0xF0 & b[i])/16];
          chars[i*2+1]  =   CHARS[(0x0F & b[i])%16];
          
        }
        return new String(chars);
    }
    
    /**
     * decode a hexidecimal string into an array of bytes
     * <p>If it is prefixed with '0x' this will be removed first.
     * <p>If the String has an odd length '0' will be prepended
     * @param s String, the hexidecimal String to decode
     * @return An array of bytes
     * @throws NullPointerException, if String is null
     */
    public final static byte[] decode(String s) {
        if (s==null) throw new NullPointerException("no String to digest");
        if (s.startsWith("0x")) s=s.substring(2);
        if (s.length()%2!=0) s="0"+s;
        char[] c= s.toCharArray();
        byte[] b= new byte[s.length()/2];
        for (int i=0;i<b.length;i++) {
            b[i]= (byte) (Character.digit(c[i*2],16)*16 + Character.digit(c[i*2+1],16));
        }
        return b;
    }
}
