/* 	JavaHelper.java
 *	Copyright (c) 2004-2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: 26-nov-2004
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
 * [When]		[Who]					[What]
 * 3-mrt-2005	dennis@brains2b.nl		remove # from objectName	
 * 25-11-2006   dennis@brains2b.nl      reimplemented naming for speed
 * 30-06-2007   dennis@brains2b.nl      fixes for javadoc	
 */
package org.brains2b.util;

/** [Short description]
 *  [Long description]
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.12.1 [30-06-2007]
 */
public final class JavaHelper {

    private JavaHelper() {
        super();
    }

    /**
     * Makes a valid, well formatted java Object name from a String
     * replaces spaces and underscores with InitCapped words
     * @param str String the needs to be made into Objectname
     * @return String valid Object name, throws NullPointerException
     * if str is null
     * @see StringHelper#initCaps(String,char)
     * @see StringHelper#stripper(String,char)
     */
    public static String objectName(String str) {
        StringBuffer out = new StringBuffer(variableName(str));
        char c = Character.toUpperCase(out.charAt(0));
        out.setCharAt(0, c);
        return out.toString();
    }

    /**
     * Returns the single objectName from possible plural name
     * use this only with English plurals!
     * @param str String the possible plural name
     * @return String the single name from this plural, or
     * the original String, , throws NullPointerException
     * if str is null
     * @see #objectName(String)
     */
    public static String singleName(String str) {
        str = objectName(str);
        if (str.endsWith("s")) {
            if (str.endsWith("ies")) {
                str = str.substring(0, str.length() - 3) + "y";
            } else {
                str = str.substring(0, str.length() - 1);
            }
        }
        return str;
    }

    /**
     * Makes a valid java member name by first making it into
     * a javaName and then appending 'm_' to it.
     * @param str String, the String that needs to be transformed
     * @return String, the String made into a member name. throws NullPointerException
     * if str is null
     * @see #objectName(String)
     */
    public static String memberName(String str) {
        return "m_" + variableName(str);
    }

    public static String variableName(String str) {
        if (str == null) {
            throw new NullPointerException("java name cannot be 'null'");
        }
        StringBuffer sb = new StringBuffer();
        str = str.trim();
        for (int i=0;i<str.length();i++) {
            char c = str.charAt(i);
            if (c==' ' || c =='-' || c=='_') {
                c=str.charAt(++i);
                sb.append(Character.toUpperCase(c));
            } else if (c!='#') {
                sb.append(Character.toLowerCase(c));
            }
        }
        
        return sb.toString();
    }

}
